=== modified file 'drizzled/sql_error.cc'
--- drizzled/sql_error.cc	2009-06-08 13:39:05 +0000
+++ drizzled/sql_error.cc	2009-08-10 18:16:21 +0000
@@ -195,7 +195,8 @@
   { C_STRING_WITH_LEN("?") }
 };
 
-bool mysqld_show_warnings(Session *session, uint32_t levels_to_show)
+bool mysqld_show_warnings(Session *session,
+                          bitset<DRIZZLE_ERROR::NUM_ERRORS> &levels_to_show)
 {
   List<Item> field_list;
 
@@ -219,7 +220,7 @@
   while ((err= it++))
   {
     /* Skip levels that the user is not interested in */
-    if (!(levels_to_show & ((ulong) 1 << err->level)))
+    if (! levels_to_show.test(err->level))
       continue;
     if (++idx <= unit->offset_limit_cnt)
       continue;

=== modified file 'drizzled/sql_error.h'
--- drizzled/sql_error.h	2009-03-24 17:33:03 +0000
+++ drizzled/sql_error.h	2009-08-10 18:16:21 +0000
@@ -23,9 +23,12 @@
 #include <drizzled/sql_alloc.h>
 #include <drizzled/plugin/storage_engine.h>
 
+#include <bitset>
+
 class DRIZZLE_ERROR: public Sql_alloc
 {
 public:
+  static const uint32_t NUM_ERRORS= 4;
   enum enum_warning_level
   { WARN_LEVEL_NOTE, WARN_LEVEL_WARN, WARN_LEVEL_ERROR, WARN_LEVEL_END};
 
@@ -48,7 +51,8 @@
 void push_warning_printf(Session *session, DRIZZLE_ERROR::enum_warning_level level,
 			 uint32_t code, const char *format, ...);
 void drizzle_reset_errors(Session *session, bool force);
-bool mysqld_show_warnings(Session *session, uint32_t levels_to_show);
+bool mysqld_show_warnings(Session *session, 
+                          std::bitset<DRIZZLE_ERROR::NUM_ERRORS> &levels_to_show);
 
 extern const LEX_STRING warning_level_names[];
 

=== modified file 'drizzled/statement/show_errors.cc'
--- drizzled/statement/show_errors.cc	2009-08-10 18:03:39 +0000
+++ drizzled/statement/show_errors.cc	2009-08-10 18:16:21 +0000
@@ -23,11 +23,15 @@
 #include <drizzled/session.h>
 #include <drizzled/statement/show_errors.h>
 
+#include <bitset>
+
+using namespace std;
 using namespace drizzled;
 
 bool statement::ShowErrors::execute()
 {
-  bool res= mysqld_show_warnings(session, (uint32_t)
-			        (1L << (uint32_t) DRIZZLE_ERROR::WARN_LEVEL_ERROR));
+  bitset<DRIZZLE_ERROR::NUM_ERRORS> warning_levels;
+  warning_levels.set(DRIZZLE_ERROR::WARN_LEVEL_ERROR);
+  bool res= mysqld_show_warnings(session, warning_levels);
   return res;
 }

=== modified file 'drizzled/statement/show_warnings.cc'
--- drizzled/statement/show_warnings.cc	2009-08-10 18:03:39 +0000
+++ drizzled/statement/show_warnings.cc	2009-08-10 18:16:21 +0000
@@ -23,14 +23,17 @@
 #include <drizzled/session.h>
 #include <drizzled/statement/show_warnings.h>
 
+#include <bitset>
+
+using namespace std;
 using namespace drizzled;
 
 bool statement::ShowWarnings::execute()
 {
-  bool res= mysqld_show_warnings(session, (uint32_t)
-			       ((1L << (uint32_t) DRIZZLE_ERROR::WARN_LEVEL_NOTE) |
-			        (1L << (uint32_t) DRIZZLE_ERROR::WARN_LEVEL_WARN) |
-			        (1L << (uint32_t) DRIZZLE_ERROR::WARN_LEVEL_ERROR)
-			       ));
+  bitset<DRIZZLE_ERROR::NUM_ERRORS> warning_levels;
+  warning_levels.set(DRIZZLE_ERROR::WARN_LEVEL_NOTE);
+  warning_levels.set(DRIZZLE_ERROR::WARN_LEVEL_WARN);
+  warning_levels.set(DRIZZLE_ERROR::WARN_LEVEL_ERROR);
+  bool res= mysqld_show_warnings(session, warning_levels);
   return res;
 }

